# Libraries

* [Domotica/RF433](https://github.com/mikaelpatel/Cosa-Domotica)
* [ICMP ping](https://github.com/mikaelpatel/Cosa-ICMP) +ICMP
* [INA219 high-side voltage/current/power sensor](https://github.com/jeditekunum/CosaINA219)
* [HTTP support](https://github.com/mikaelpatel/Cosa-HTTP) +HTTP
* [Goggle Protocol Buffers](https://github.com/mikaelpatel/Cosa-ProtocolBuffer) +ProtocolBuffer
* [GPS with MT/MTK3339](https://github.com/jeditekunum/CosaGPS)
* [OLED SSD1306/SH1106](https://github.com/jeditekunum/CosaOLED)
* [MQTT client](https://github.com/mikaelpatel/Cosa-MQTT) +MQTT
* [NEXA Wireless Protocol](https://github.com/mikaelpatel/Cosa-NEXA) +NEXA
* [NMEA and ublox GPS parser](https://github.com/SlashDevin/CosaGPS)
* [NTP client](https://github.com/mikaelpatel/Cosa-NTP) +NTP
* [Shell support](https://github.com/mikaelpatel/Cosa-Shell) +Shell
* [SNMP agent](https://github.com/mikaelpatel/Cosa-SNMP) +SNMP
* [Telnet server](https://github.com/mikaelpatel/Cosa-Telnet) +Telnet
* [ThingSpeak support](https://github.com/mikaelpatel/Cosa-ThingSpeak) +ThingSpeak
* [Timezon](https://github.com/jeditekunum/CosaTimezone)
* [TM1637 4 digit 7 segment LED display](https://github.com/jeditekunum/CosaTM1637)
* [UML actors](https://github.com/mikaelpatel/Cosa-UML) +UML

If using Git, libraries with a "+[name]" are submodules that can be downloaded with
`git submodule init -- libraries/[name]`

They can subsequently be updated by issuing the command
`git submodule update --remote -- libraries/[name]`

# Tools

* [BDF font converter](https://github.com/jeditekunum/bdf2uc)
* [AVR ISP](https://github.com/mikaelpatel/Cosa-AVR) +AVR


# Applications

* [ElFi is a Do It Yourself Home Automation System](https://github.com/sehlstrom/ElFi)
* [NexaController](https://github.com/balmli/NexaController)
